#!/bin/sh
#
# Renames and translates files between MS-DOS and Unix format.  This
# script will only run on Unix.
#
# NOTE: Assumes text files which end with ^Z have nothing but ^Z at the end.
# 
# 
# Determine direction of conversion.
if [ -r copying -a -d io/testsunl.src ]; then
    convert=dos2unix
    # Move directories first
    mv io/testsunl.src io/test_sun_lwp.src
    mv gen/testpclw.src gen/test_pc_lwp.src
elif [ -r COPYING -a -d io/test_sun_lwp.src ]; then
    convert=unix2dos
    # Move directories last
else
    echo It seems that you have screwed something up.  
    echo Read this script and try and figure out what you did.
    exit 1
fi

# Use current directory so that we don't jump partions and have to copy.
Tmp=`basename $0`.$$
dos2unix()
    # $1: source
    # $2: dest
{
    tr -d '[\015\032]' < $1 > $Tmp
    rm $1  # Remove before in case files are the same name!
    mv $Tmp $2
} # dos2unix

unix2dos()
    # $1: dest
    # $2: source
{
    # CAUTION: roles are reversed.
    sed -e 's,$,
,' $2 > $Tmp
    rm $2  # Remove before in case files are the same name!
    mv $Tmp $1
} # unix2dos

# Binary files don't get converted
# conf/sun/m2pp
# conf/pc/make.exe
# conf/pc/m2pp.exe
# conf/lg2/l2erts.lwp
# conf/lg2/m2lwp.exe

# Don't convert the convert program!
# $convert conf/distrib/dos_unix.sh conf/distrib/dos_unix.sh

# Now the regular files, always have different name first for check 
# in direction.
$convert copying COPYING
$convert readme README
$convert header HEADER
$convert todo TODO
$convert bugs BUGS
$convert conf/sun/depend.mak conf/sun/depend.mak
$convert conf/sun/environ.mak conf/sun/environ.mak
$convert conf/sun/makefile conf/sun/makefile
$convert conf/sun/mainmake conf/sun/mainmake
$convert conf/sun/mk_insta conf/sun/mk_install
$convert conf/sun/rules.mak conf/sun/rules.mak
$convert conf/lg2/depend.mak conf/lg2/depend.mak
$convert conf/lg2/environ.mak conf/lg2/environ.mak
$convert conf/lg2/makefile conf/lg2/makefile
$convert conf/lg2/mk_m2c.bat conf/lg2/mk_m2c.bat
$convert conf/lg2/mk_m2dep.bat conf/lg2/mk_m2dep.bat
$convert conf/lg2/mk_m2exe.bat conf/lg2/mk_m2exe.bat
$convert conf/lg2/mk_m2l.bat conf/lg2/mk_m2l.bat
$convert conf/lg2/rules.mak conf/lg2/rules.mak
$convert conf/pc/mainmake.bat conf/pc/mainmake.bat
$convert conf/pc/mk_inst.bat conf/pc/mk_inst.bat
$convert conf/lg3/depend.mak conf/lg3/depend.mak
$convert conf/lg3/environ.mak conf/lg3/environ.mak
$convert conf/lg3/makefile conf/lg3/makefile
$convert conf/lg3/mk_m2c.bat conf/lg3/mk_m2c.bat
$convert conf/lg3/mk_m2dep.bat conf/lg3/mk_m2dep.bat
$convert conf/lg3/mk_m2l.bat conf/lg3/mk_m2l.bat
$convert conf/lg3/rules.mak conf/lg3/rules.mak
$convert conf/distrib/lg2_inst.bat conf/distrib/lg2_inst.bat
$convert conf/distrib/lg2_only.bat conf/distrib/lg2_only.bat
$convert conf/distrib/lg3_inst.bat conf/distrib/lg3_inst.bat
$convert conf/distrib/lg3_only.bat conf/distrib/lg3_only.bat
$convert conf/distrib/nfs_xfer.bat conf/distrib/nfs_xfer.bat
$convert conf/distrib/pc_xfer.bat conf/distrib/pc_xfer.bat
$convert conf/distrib/sun_inst.sh conf/distrib/sun_inst.sh
$convert conf/distrib/sun_only.sh conf/distrib/sun_only.sh
$convert porting/hackname.def porting/HackNameLists.def
$convert porting/hackname.mod porting/HackNameLists.mod
$convert porting/hacktext.def porting/HackTextIO.def
$convert porting/hacktext.mod porting/HackTextIO.mod
$convert porting/readme porting/README
$convert porting/depend.mak porting/depend.mak
$convert porting/hackm2pp.mod porting/hackm2pp.mod
$convert misc/readme misc/README
$convert misc/x.dpp misc/X.dpp
$convert misc/xlib.dpp misc/Xlib.dpp
$convert misc/xproc.dpp misc/Xproc.dpp
$convert misc/xutil.dpp misc/Xutil.dpp
$convert misc/logi2bug.txt misc/logi2bug.txt
$convert misc/logi3bug.txt misc/logi3bug.txt
$convert misc/sunbugs.shr misc/sunbugs.shr
$convert misc/dbx.shr misc/dbx.shr
$convert fio/shared.src/conffio.dpp fio/shared.src/ConfFIO.dpp
$convert fio/shared.src/conffio.mpp fio/shared.src/ConfFIO.mpp
$convert fio/shared.src/convertf.dpp fio/shared.src/ConvertFIO.dpp
$convert fio/shared.src/convertf.mpp fio/shared.src/ConvertFIO.mpp
$convert fio/shared.src/datafio.dpp fio/shared.src/DataFIO.dpp
$convert fio/shared.src/datafio.mpp fio/shared.src/DataFIO.mpp
$convert fio/shared.src/errorfio.dpp fio/shared.src/ErrorFIO.dpp
$convert fio/shared.src/errorfio.mpp fio/shared.src/ErrorFIO.mpp
$convert fio/shared.src/fiobase.dpp fio/shared.src/FIOBase.dpp
$convert fio/shared.src/fiobase.mpp fio/shared.src/FIOBase.mpp
$convert fio/shared.src/fiobool.dpp fio/shared.src/FIOBool.dpp
$convert fio/shared.src/fiobool.mpp fio/shared.src/FIOBool.mpp
$convert fio/shared.src/fiocard.dpp fio/shared.src/FIOCard.dpp
$convert fio/shared.src/fiocard.mpp fio/shared.src/FIOCard.mpp
$convert fio/shared.src/fioint.dpp fio/shared.src/FIOInt.dpp
$convert fio/shared.src/fioint.mpp fio/shared.src/FIOInt.mpp
$convert fio/shared.src/fiopriva.dpp fio/shared.src/FIOPRIVATE.dpp
$convert fio/shared.src/fiopriva.mpp fio/shared.src/FIOPRIVATE.mpp
$convert fio/shared.src/fioreal.dpp fio/shared.src/FIOReal.dpp
$convert fio/shared.src/fioreal.mpp fio/shared.src/FIOReal.mpp
$convert fio/shared.src/fioscree.dpp fio/shared.src/FIOScreen.dpp
$convert fio/shared.src/fioscree.mpp fio/shared.src/FIOScreen.mpp
$convert fio/shared.src/fiostrin.dpp fio/shared.src/FIOString.dpp
$convert fio/shared.src/fiostrin.mpp fio/shared.src/FIOString.mpp
$convert fio/shared.src/formatio.dpp fio/shared.src/FormatIO.dpp
$convert fio/shared.src/formatio.mpp fio/shared.src/FormatIO.mpp
$convert fio/shared.src/simplefi.dpp fio/shared.src/SimpleFIO.dpp
$convert fio/shared.src/simplefi.mpp fio/shared.src/SimpleFIO.mpp
$convert fio/test.src/fiotest.mpp fio/test.src/FIOTest.mpp
$convert fio/test.src/tbool.mpp fio/test.src/tBool.mpp
$convert fio/test.src/tdatafio.mpp fio/test.src/tDataFIO.mpp
$convert fio/test.src/tfioscre.mpp fio/test.src/tFIOScreen.mpp
$convert fio/test.src/tintcard.mpp fio/test.src/tIntCard.mpp
$convert fio/test.src/tisvalid.mpp fio/test.src/tIsValid.mpp
$convert fio/test.src/treal.mpp fio/test.src/tReal.mpp
$convert fio/test.src/tsimplef.mpp fio/test.src/tSimpleFIO.mpp
$convert fio/test.src/tstring.mpp fio/test.src/tString.mpp
$convert io/sun.src/confbina.mpp io/sun.src/ConfBinaryIO.mpp
$convert io/sun.src/dirio.mpp io/sun.src/DirIO.mpp
$convert io/sun.src/ioconsts.dpp io/sun.src/IOConsts.dpp
$convert io/sun.src/ionames.mpp io/sun.src/IONames.mpp
$convert io/sun.src/screenio.mpp io/sun.src/ScreenIO.mpp
$convert io/sun.src/unixbina.dpp io/sun.src/UnixBinaryIO.dpp
$convert io/sun.src/unixbina.mpp io/sun.src/UnixBinaryIO.mpp
$convert io/sun.src/unixioer.dpp io/sun.src/UnixIOErrors.dpp
$convert io/sun.src/unixioer.mpp io/sun.src/UnixIOErrors.mpp
$convert io/sun.src/unixiona.dpp io/sun.src/UnixIONames.dpp
$convert io/sun.src/unixiona.mpp io/sun.src/UnixIONames.mpp
$convert io/pc.src/confbina.mpp io/pc.src/ConfBinaryIO.mpp
$convert io/pc.src/dirio.mpp io/pc.src/DirIO.mpp
$convert io/pc.src/dosbinar.dpp io/pc.src/DosBinaryIO.dpp
$convert io/pc.src/dosbinar.mpp io/pc.src/DosBinaryIO.mpp
$convert io/pc.src/dosioerr.dpp io/pc.src/DosIOErrors.dpp
$convert io/pc.src/dosioerr.mpp io/pc.src/DosIOErrors.mpp
$convert io/pc.src/dosionam.dpp io/pc.src/DosIONames.dpp
$convert io/pc.src/dosionam.mpp io/pc.src/DosIONames.mpp
$convert io/pc.src/ioconsts.dpp io/pc.src/IOConsts.dpp
$convert io/pc.src/ionames.mpp io/pc.src/IONames.mpp
$convert io/pc.src/keyboard.dpp io/pc.src/Keyboard.dpp
$convert io/pc.src/keyboard.mpp io/pc.src/Keyboard.mpp
$convert io/pc.src/screenio.mpp io/pc.src/ScreenIO.mpp
$convert io/lwp.src/iomonito.dpp io/lwp.src/IOMonitors.dpp
$convert io/lwp.src/iomonito.mpp io/lwp.src/IOMonitors.mpp
$convert io/shared.src/binaryio.dpp io/shared.src/BinaryIO.dpp
$convert io/shared.src/binaryio.mpp io/shared.src/BinaryIO.mpp
$convert io/shared.src/binarysu.dpp io/shared.src/BinarySupportIO.dpp
$convert io/shared.src/binarysu.mpp io/shared.src/BinarySupportIO.mpp
$convert io/shared.src/cardio.dpp io/shared.src/CardIO.dpp
$convert io/shared.src/cardio.mpp io/shared.src/CardIO.mpp
$convert io/shared.src/catbinar.dpp io/shared.src/CatBinaryIO.dpp
$convert io/shared.src/catbinar.mpp io/shared.src/CatBinaryIO.mpp
$convert io/shared.src/confbina.dpp io/shared.src/ConfBinaryIO.dpp
$convert io/shared.src/dirio.dpp io/shared.src/DirIO.dpp
$convert io/shared.src/ioconsts.mpp io/shared.src/IOConsts.mpp
$convert io/shared.src/ioerrors.dpp io/shared.src/IOErrors.dpp
$convert io/shared.src/ioerrors.mpp io/shared.src/IOErrors.mpp
$convert io/shared.src/ionames.dpp io/shared.src/IONames.dpp
$convert io/shared.src/iosearch.dpp io/shared.src/IOSearchPaths.dpp
$convert io/shared.src/iosearch.mpp io/shared.src/IOSearchPaths.mpp
$convert io/shared.src/ioversio.dpp io/shared.src/IOVersions.dpp
$convert io/shared.src/ioversio.mpp io/shared.src/IOVersions.mpp
$convert io/shared.src/intio.dpp io/shared.src/IntIO.dpp
$convert io/shared.src/intio.mpp io/shared.src/IntIO.mpp
$convert io/shared.src/realio.dpp io/shared.src/RealIO.dpp
$convert io/shared.src/realio.mpp io/shared.src/RealIO.mpp
$convert io/shared.src/screenio.dpp io/shared.src/ScreenIO.dpp
$convert io/shared.src/simpleio.dpp io/shared.src/SimpleIO.dpp
$convert io/shared.src/simpleio.mpp io/shared.src/SimpleIO.mpp
$convert io/shared.src/stringbi.dpp io/shared.src/StringBinaryIO.dpp
$convert io/shared.src/stringbi.mpp io/shared.src/StringBinaryIO.mpp
$convert io/shared.src/stringio.dpp io/shared.src/StringIO.dpp
$convert io/shared.src/stringio.mpp io/shared.src/StringIO.mpp
$convert io/shared.src/textio.dpp io/shared.src/TextIO.dpp
$convert io/shared.src/textio.mpp io/shared.src/TextIO.mpp
$convert io/shared.src/textiopr.dpp io/shared.src/TextIOPRIVATE.dpp
$convert io/shared.src/textiopr.mpp io/shared.src/TextIOPRIVATE.mpp
$convert io/shared.src/textsupp.dpp io/shared.src/TextSupportIO.dpp
$convert io/shared.src/textsupp.mpp io/shared.src/TextSupportIO.mpp
$convert io/test.src/bintest.mpp io/test.src/BinTest.mpp
$convert io/test.src/cardiote.mpp io/test.src/CardIOTest.mpp
$convert io/test.src/cardioti.mpp io/test.src/CardIOTimer.mpp
$convert io/test.src/changedi.mpp io/test.src/ChangeDir.mpp
$convert io/test.src/dirtest.mpp io/test.src/DirTest.mpp
$convert io/test.src/hello.mpp io/test.src/Hello.mpp
$convert io/test.src/intiotes.mpp io/test.src/IntIOTest.mpp
$convert io/test.src/realiote.mpp io/test.src/RealIOTest.mpp
$convert io/test.src/realioti.mpp io/test.src/RealIOTimer.mpp
$convert io/test.src/tcopy.mpp io/test.src/tCopy.mpp
$convert io/test.src/tcopyobj.mpp io/test.src/tCopyObject.mpp
$convert io/test.src/tdirioli.mpp io/test.src/tDirIOList.mpp
$convert io/test.src/tionames.mpp io/test.src/tIONames.mpp
$convert io/test.src/tioversi.mpp io/test.src/tIOVersions.mpp
$convert io/test.src/tlistwit.mpp io/test.src/tListWithInfo.mpp
$convert io/test.src/tscreeni.mpp io/test.src/tScreenIO.mpp
$convert io/test.src/tstringb.mpp io/test.src/tStringBinaryIO.mpp
$convert io/test_pc.src/tkeyboar.mpp io/test_pc.src/tKeyboard.mpp
$convert io/test_sun.src/ttcopy.sh io/test_sun.src/ttCopy.sh
$convert io/sun_lwp.src/unixasyn.dpp io/sun_lwp.src/UnixAsynchIO.dpp
$convert io/sun_lwp.src/unixasyn.mpp io/sun_lwp.src/UnixAsynchIO.mpp
$convert io/test_sun_lwp.src/tasynchr.mpp io/test_sun_lwp.src/tAsynchRealIO.mpp
$convert gen/sun_lwp.src/interrup.mpp gen/sun_lwp.src/Interrupts.mpp
$convert gen/sun_lwp.src/taskcons.dpp gen/sun_lwp.src/TaskConsts.dpp
$convert gen/sun_lwp.src/taskcons.mpp gen/sun_lwp.src/TaskConsts.mpp
$convert gen/sun_lwp.src/tasktime.mpp gen/sun_lwp.src/TaskTime.mpp
$convert gen/sun_lwp.src/tasksasm.dpp gen/sun_lwp.src/TasksAsm.dpp
$convert gen/sun_lwp.src/taskspri.dpp gen/sun_lwp.src/TasksPRIVATE.dpp
$convert gen/sun_lwp.src/taskspri.mpp gen/sun_lwp.src/TasksPRIVATE.mpp
$convert gen/sun_lwp.src/unixmoni.dpp gen/sun_lwp.src/UnixMonitor.dpp
$convert gen/sun_lwp.src/unixmoni.mpp gen/sun_lwp.src/UnixMonitor.mpp
$convert gen/test.dat/readme gen/test.dat/README
$convert gen/test.src/gentesti.dpp gen/test.src/GenTestIO.dpp
$convert gen/test.src/stringli.dpp gen/test.src/StringLib.dpp
$convert gen/test.src/stringli.mpp gen/test.src/StringLib.mpp
$convert gen/test.src/testcrc1.mpp gen/test.src/TestCRC16.mpp
$convert gen/test.src/testcard.mpp gen/test.src/TestCardConv.mpp
$convert gen/test.src/testio.dpp gen/test.src/TestIO.dpp
$convert gen/test.src/testio.mpp gen/test.src/TestIO.mpp
$convert gen/test.src/testintc.mpp gen/test.src/TestIntConv.mpp
$convert gen/test.src/testname.mpp gen/test.src/TestNameLists.mpp
$convert gen/test.src/testreal.mpp gen/test.src/TestRealConv.mpp
$convert gen/test.src/teststri.mpp gen/test.src/TestStrings.mpp
$convert gen/test.src/testsyst.dpp gen/test.src/TestSystem.dpp
$convert gen/test.src/testsyst.mpp gen/test.src/TestSystem.mpp
$convert gen/test.src/tbytes.mpp gen/test.src/tBytes.mpp
$convert gen/test.src/tdebugfl.mpp gen/test.src/tDebugFlags.mpp
$convert gen/test.src/thello.mpp gen/test.src/tHello.mpp
$convert gen/test.src/tprogarg.mpp gen/test.src/tProgArgs.mpp
$convert gen/test.src/tprogenv.mpp gen/test.src/tProgEnviron.mpp
$convert gen/test.src/tqstring.mpp gen/test.src/tQStrings.mpp
$convert gen/test.src/tsystype.mpp gen/test.src/tSysTypes.mpp
$convert gen/test_sun.src/gentesti.mpp gen/test_sun.src/GenTestIO.mpp
$convert gen/test_sun.src/ttestcar.sh gen/test_sun.src/TTestCardConvert.sh
$convert gen/test_sun.src/ttestgen.sh gen/test_sun.src/TTestGeneralLib.sh
$convert gen/test_sun.src/ttestint.sh gen/test_sun.src/TTestIntConvert.sh
$convert gen/test_sun.src/ttestrea.sh gen/test_sun.src/TTestRealConvert.sh
$convert gen/test_sun.src/testdate.dpp gen/test_sun.src/TestDate.dpp
$convert gen/pc.src/card32.dpp gen/pc.src/Card32.dpp
$convert gen/pc.src/card32.mpp gen/pc.src/Card32.mpp
$convert gen/pc.src/dos.dpp gen/pc.src/DOS.dpp
$convert gen/pc.src/dos.mpp gen/pc.src/DOS.mpp
$convert gen/pc.src/i8086.dpp gen/pc.src/I8086.dpp
$convert gen/pc.src/i8086.mpp gen/pc.src/I8086.mpp
$convert gen/pc.src/progenvi.mpp gen/pc.src/ProgEnviron.mpp
$convert gen/pc.src/safestor.mpp gen/pc.src/SafeStorage.mpp
$convert gen/pc.src/systypes.dpp gen/pc.src/SysTypes.dpp
$convert gen/pc.src/systypes.mpp gen/pc.src/SysTypes.mpp
$convert gen/pc_lwp.src/dosmonit.dpp gen/pc_lwp.src/DosMonitor.dpp
$convert gen/pc_lwp.src/dosmonit.mpp gen/pc_lwp.src/DosMonitor.mpp
$convert gen/pc_lwp.src/interrup.mpp gen/pc_lwp.src/Interrupts.mpp
$convert gen/pc_lwp.src/taskcons.dpp gen/pc_lwp.src/TaskConsts.dpp
$convert gen/pc_lwp.src/taskcons.mpp gen/pc_lwp.src/TaskConsts.mpp
$convert gen/pc_lwp.src/tasktime.mpp gen/pc_lwp.src/TaskTime.mpp
$convert gen/pc_lwp.src/taskspri.dpp gen/pc_lwp.src/TasksPRIVATE.dpp
$convert gen/pc_lwp.src/taskspri.mpp gen/pc_lwp.src/TasksPRIVATE.mpp
$convert gen/shared.src/ascii.dpp gen/shared.src/ASCII.dpp
$convert gen/shared.src/ascii.mpp gen/shared.src/ASCII.mpp
$convert gen/shared.src/bytes.dpp gen/shared.src/Bytes.dpp
$convert gen/shared.src/bytes.mpp gen/shared.src/Bytes.mpp
$convert gen/shared.src/crc16.dpp gen/shared.src/CRC16.dpp
$convert gen/shared.src/crc16.mpp gen/shared.src/CRC16.mpp
$convert gen/shared.src/cardconv.dpp gen/shared.src/CardConvert.dpp
$convert gen/shared.src/cardconv.mpp gen/shared.src/CardConvert.mpp
$convert gen/shared.src/chars.dpp gen/shared.src/Chars.dpp
$convert gen/shared.src/chars.mpp gen/shared.src/Chars.mpp
$convert gen/shared.src/debugfla.dpp gen/shared.src/DebugFlags.dpp
$convert gen/shared.src/debugfla.mpp gen/shared.src/DebugFlags.mpp
$convert gen/shared.src/genconst.dpp gen/shared.src/GenConsts.dpp
$convert gen/shared.src/genconst.mpp gen/shared.src/GenConsts.mpp
$convert gen/shared.src/intconve.dpp gen/shared.src/IntConvert.dpp
$convert gen/shared.src/intconve.mpp gen/shared.src/IntConvert.mpp
$convert gen/shared.src/intrinsi.dpp gen/shared.src/Intrinsics.dpp
$convert gen/shared.src/intrinsi.mpp gen/shared.src/Intrinsics.mpp
$convert gen/shared.src/lists.dpp gen/shared.src/Lists.dpp
$convert gen/shared.src/lists.mpp gen/shared.src/Lists.mpp
$convert gen/shared.src/modinit.dpp gen/shared.src/ModInit.dpp
$convert gen/shared.src/modinit.mpp gen/shared.src/ModInit.mpp
$convert gen/shared.src/namelist.dpp gen/shared.src/NameLists.dpp
$convert gen/shared.src/namelist.mpp gen/shared.src/NameLists.mpp
$convert gen/shared.src/notices.dpp gen/shared.src/Notices.dpp
$convert gen/shared.src/notices.mpp gen/shared.src/Notices.mpp
$convert gen/shared.src/objects.dpp gen/shared.src/Objects.dpp
$convert gen/shared.src/objects.mpp gen/shared.src/Objects.mpp
$convert gen/shared.src/progargs.dpp gen/shared.src/ProgArgs.dpp
$convert gen/shared.src/progargs.mpp gen/shared.src/ProgArgs.mpp
$convert gen/shared.src/progenvi.dpp gen/shared.src/ProgEnviron.dpp
$convert gen/shared.src/progerr.dpp gen/shared.src/ProgErr.dpp
$convert gen/shared.src/progerro.dpp gen/shared.src/ProgErrOutput.dpp
$convert gen/shared.src/progerro.mpp gen/shared.src/ProgErrOutput.mpp
$convert gen/shared.src/qstrings.dpp gen/shared.src/QStrings.dpp
$convert gen/shared.src/qstrings.mpp gen/shared.src/QStrings.mpp
$convert gen/shared.src/randomnu.dpp gen/shared.src/RandomNumbers.dpp
$convert gen/shared.src/randomnu.mpp gen/shared.src/RandomNumbers.mpp
$convert gen/shared.src/realconv.dpp gen/shared.src/RealConvert.dpp
$convert gen/shared.src/realconv.mpp gen/shared.src/RealConvert.mpp
$convert gen/shared.src/safestor.dpp gen/shared.src/SafeStorage.dpp
$convert gen/shared.src/strings.dpp gen/shared.src/Strings.dpp
$convert gen/shared.src/strings.mpp gen/shared.src/Strings.mpp
$convert gen/sun.src/asmlib.s gen/sun.src/AsmLib.s
$convert gen/sun.src/mc68881.dpp gen/sun.src/MC68881.dpp
$convert gen/sun.src/progenvi.mpp gen/sun.src/ProgEnviron.mpp
$convert gen/sun.src/progerr.mpp gen/sun.src/ProgErr.mpp
$convert gen/sun.src/safestor.mpp gen/sun.src/SafeStorage.mpp
$convert gen/sun.src/systypes.dpp gen/sun.src/SysTypes.dpp
$convert gen/sun.src/systypes.mpp gen/sun.src/SysTypes.mpp
$convert gen/sun.src/_environ.dpp gen/sun.src/UnixCenviron.dpp
$convert gen/sun.src/_errno.dpp gen/sun.src/UnixCerrno.dpp
$convert gen/sun.src/_exit.dpp gen/sun.src/UnixCexit.dpp
$convert gen/sun.src/_fcntl.dpp gen/sun.src/UnixCfcntl.dpp
$convert gen/sun.src/_host.dpp gen/sun.src/UnixChost.dpp
$convert gen/sun.src/_ioctl.dpp gen/sun.src/UnixCioctl.dpp
$convert gen/sun.src/_ipc.dpp gen/sun.src/UnixCipc.dpp
$convert gen/sun.src/_malloc.dpp gen/sun.src/UnixCmalloc.dpp
$convert gen/sun.src/_math.dpp gen/sun.src/UnixCmath.dpp
$convert gen/sun.src/_process.dpp gen/sun.src/UnixCprocess.dpp
$convert gen/sun.src/_rasterf.dpp gen/sun.src/UnixCrasterfile.dpp
$convert gen/sun.src/_signal.dpp gen/sun.src/UnixCsignal.dpp
$convert gen/sun.src/_sys_dir.dpp gen/sun.src/UnixCsys_dir.dpp
$convert gen/sun.src/_sys_fil.dpp gen/sun.src/UnixCsys_file.dpp
$convert gen/sun.src/_sys_par.dpp gen/sun.src/UnixCsys_param.dpp
$convert gen/sun.src/_sys_res.dpp gen/sun.src/UnixCsys_resource.dpp
$convert gen/sun.src/_sys_sta.dpp gen/sun.src/UnixCsys_stat.dpp
$convert gen/sun.src/_sys_tim.dpp gen/sun.src/UnixCsys_time.dpp
$convert gen/sun.src/_sys_typ.dpp gen/sun.src/UnixCsys_types.dpp
$convert gen/sun.src/_termcap.dpp gen/sun.src/UnixCtermcap.dpp
$convert gen/sun.src/_tty.dpp gen/sun.src/UnixCtty.dpp
$convert gen/sun.src/_types.dpp gen/sun.src/UnixCtypes.dpp
$convert gen/sun.src/unixerro.dpp gen/sun.src/UnixError.dpp
$convert gen/sun.src/unixerro.mpp gen/sun.src/UnixError.mpp
$convert gen/sun.src/unixmath.dpp gen/sun.src/UnixMathError.dpp
$convert gen/lwp.src/interrup.dpp gen/lwp.src/Interrupts.dpp
$convert gen/lwp.src/taskdebu.dpp gen/lwp.src/TaskDebug.dpp
$convert gen/lwp.src/taskdebu.mpp gen/lwp.src/TaskDebug.mpp
$convert gen/lwp.src/taskinfo.dpp gen/lwp.src/TaskInfo.dpp
$convert gen/lwp.src/taskinfo.mpp gen/lwp.src/TaskInfo.mpp
$convert gen/lwp.src/taskmess.dpp gen/lwp.src/TaskMessages.dpp
$convert gen/lwp.src/taskmess.mpp gen/lwp.src/TaskMessages.mpp
$convert gen/lwp.src/taskmoni.dpp gen/lwp.src/TaskMonitors.dpp
$convert gen/lwp.src/taskmoni.mpp gen/lwp.src/TaskMonitors.mpp
$convert gen/lwp.src/tasknoti.dpp gen/lwp.src/TaskNotices.dpp
$convert gen/lwp.src/tasknoti.mpp gen/lwp.src/TaskNotices.mpp
$convert gen/lwp.src/tasksema.dpp gen/lwp.src/TaskSemaphores.dpp
$convert gen/lwp.src/tasksema.mpp gen/lwp.src/TaskSemaphores.mpp
$convert gen/lwp.src/tasktime.dpp gen/lwp.src/TaskTime.dpp
$convert gen/lwp.src/tasks.dpp gen/lwp.src/Tasks.dpp
$convert gen/lwp.src/tasks.mpp gen/lwp.src/Tasks.mpp
$convert gen/test_pc.src/gentesti.mpp gen/test_pc.src/GenTestIO.mpp
$convert gen/test.src/tcrash.mpp gen/test.src/tCrash.mpp
$convert gen/test_lwp.src/inttasks.mpp gen/test_lwp.src/IntTasks.mpp
$convert gen/test_lwp.src/pingpong.mpp gen/test_lwp.src/PingPong.mpp
$convert gen/test_lwp.src/thello.mpp gen/test_lwp.src/tHello.mpp
$convert gen/test_lwp.src/tint1.mpp gen/test_lwp.src/tInt1.mpp
$convert gen/test_lwp.src/tint2.mpp gen/test_lwp.src/tInt2.mpp
$convert gen/test_lwp.src/tmess1.mpp gen/test_lwp.src/tMess1.mpp
$convert gen/test_lwp.src/tmon1.mpp gen/test_lwp.src/tMon1.mpp
$convert gen/test_lwp.src/tmon2.mpp gen/test_lwp.src/tMon2.mpp
$convert gen/test_lwp.src/tmon3.mpp gen/test_lwp.src/tMon3.mpp
$convert gen/test_lwp.src/tmon4.mpp gen/test_lwp.src/tMon4.mpp
$convert gen/test_lwp.src/tmon5.mpp gen/test_lwp.src/tMon5.mpp
$convert gen/test_lwp.src/tmon6.mpp gen/test_lwp.src/tMon6.mpp
$convert gen/test_lwp.src/tmon7.mpp gen/test_lwp.src/tMon7.mpp
$convert gen/test_lwp.src/tmon8.mpp gen/test_lwp.src/tMon8.mpp
$convert gen/test_lwp.src/tmon9.mpp gen/test_lwp.src/tMon9.mpp
$convert gen/test_lwp.src/tmonitor.mpp gen/test_lwp.src/tMonitor.mpp
$convert gen/test_lwp.src/tsemapho.mpp gen/test_lwp.src/tSemaphore.mpp
$convert gen/test_lwp.src/tstack.mpp gen/test_lwp.src/tStack.mpp
$convert gen/test_lwp.src/ttaskinf.mpp gen/test_lwp.src/tTaskInfo.mpp
$convert gen/test_lwp.src/ttasktim.mpp gen/test_lwp.src/tTaskTime.mpp
$convert gen/test_lwp.src/tdebug1.mpp gen/test_lwp.src/tdebug1.mpp
$convert gen/test_lwp.src/tdebug2.mpp gen/test_lwp.src/tdebug2.mpp
$convert gen/test_pc_lwp.src/doctest.bat gen/test_pc_lwp.src/doctest.bat
$convert gen/test_pc_lwp.src/test.bat gen/test_pc_lwp.src/test.bat
$convert gen/lg2.src/readme gen/lg2.src/README
$convert gen/lg2.src/system.mpp gen/lg2.src/System.mpp
$convert gen/lg2.src/progerr.mpp gen/lg2.src/ProgErr.mpp
$convert gen/lg3.src/progerr.mpp gen/lg3.src/ProgErr.mpp
$convert tools/sun.src/checkcom.sh tools/sun.src/CheckComments.sh
$convert tools/sun.src/ttyreset.c tools/sun.src/ttyreset.c
$convert tools/shared.src/m2pparse.dpp tools/shared.src/M2PParser.dpp
$convert tools/shared.src/m2pparse.mpp tools/shared.src/M2PParser.mpp
$convert tools/shared.src/m2pscann.dpp tools/shared.src/M2PScanner.dpp
$convert tools/shared.src/m2pscann.mpp tools/shared.src/M2PScanner.mpp
$convert tools/shared.src/m2parser.dpp tools/shared.src/M2Parser.dpp
$convert tools/shared.src/m2parser.mpp tools/shared.src/M2Parser.mpp
$convert tools/shared.src/m2scanne.dpp tools/shared.src/M2Scanner.dpp
$convert tools/shared.src/m2scanne.mpp tools/shared.src/M2Scanner.mpp
$convert tools/shared.src/makeio.dpp tools/shared.src/MakeIO.dpp
$convert tools/shared.src/makeio.mpp tools/shared.src/MakeIO.mpp
$convert tools/shared.src/makepara.dpp tools/shared.src/MakeParameters.dpp
$convert tools/shared.src/makepara.mpp tools/shared.src/MakeParameters.mpp
$convert tools/shared.src/m2depend.mpp tools/shared.src/m2depend.mpp
$convert tools/shared.src/m2pp.mpp tools/shared.src/m2pp.mpp
$convert tools/make/readme tools/make/README
$convert tools/make/check.c tools/make/check.c
$convert tools/make/h.h tools/make/h.h
$convert tools/make/input.c tools/make/input.c
$convert tools/make/macro.c tools/make/macro.c
$convert tools/make/main.c tools/make/main.c
$convert tools/make/make.c tools/make/make.c
$convert tools/make/makefile.msc tools/make/makefile.msc
$convert tools/make/makefile.sun tools/make/makefile.sun
$convert tools/make/reader.c tools/make/reader.c
$convert tools/make/rules.c tools/make/rules.c
$convert demo/lwp.src/keyinput.dpp demo/lwp.src/KeyInput.dpp
$convert demo/lwp.src/keyinput.mpp demo/lwp.src/KeyInput.mpp
$convert demo/lwp.src/maze.dpp demo/lwp.src/Maze.dpp
$convert demo/lwp.src/maze.mpp demo/lwp.src/Maze.mpp
$convert demo/lwp.src/screen.dpp demo/lwp.src/Screen.dpp
$convert demo/lwp.src/screen.mpp demo/lwp.src/Screen.mpp
$convert demo/lwp.src/solver.mpp demo/lwp.src/Solver.mpp
$convert demo/pc_lwp.src/keyinput.mpp demo/pc_lwp.src/KeyInput.mpp
$convert demo/pc_lwp.src/lowlevel.dpp demo/pc_lwp.src/LowLevel.dpp
$convert demo/pc_lwp.src/lowlevel.mpp demo/pc_lwp.src/LowLevel.mpp
$convert demo/pc_lwp.src/screen.mpp demo/pc_lwp.src/Screen.mpp
$convert doc/bib.tex doc/Bib.tex
$convert doc/checkcom.man doc/CheckComments.man
$convert doc/classes.tex doc/Classes.tex
$convert doc/coding.tex doc/Coding.tex
$convert doc/errors.tex doc/Errors.tex
$convert doc/files.tex doc/Files.tex
$convert doc/header.tex doc/Header.tex
$convert doc/impl.tex doc/Impl.tex
$convert doc/install.tex doc/Install.tex
$convert doc/intro.tex doc/Intro.tex
$convert doc/introio.tex doc/IntroIO.tex
$convert doc/manual.tex doc/Manual.tex
$convert doc/modules.tex doc/Modules.tex
$convert doc/morefio.tex doc/MoreFIO.tex
$convert doc/objects.tex doc/Objects.tex
$convert doc/preface.tex doc/Preface.tex
$convert doc/procvar.tex doc/ProcVar.tex
$convert doc/tasksdes.tex doc/TasksDesign.tex
$convert doc/tasks.tex doc/Tasks.tex
$convert doc/bk11.sty doc/bk11.sty
$convert doc/book.sty doc/book.sty
$convert doc/copyrigh.tex doc/Copyright.tex
$convert doc/m2pp.tex doc/m2pp.tex
$convert doc/m2pp.man doc/m2pp.man
$convert doc/latex.sh doc/LaTeX.sh
$convert doc/makefile doc/makefile
$convert doc/makeinde.sh doc/MakeIndexFile.sh
$convert doc/fixindex.sh doc/FixIndex.sh
$convert examples/adtmodul.dpp examples/ADTModule.dpp
$convert examples/adtmodul.mpp examples/ADTModule.mpp
$convert examples/introio.mpp examples/IntroIO.mpp
$convert examples/files.mpp examples/Files.mpp
$convert examples/morefio.mpp examples/MoreFIO.mpp
$convert examples/delete.mpp examples/delete.mpp
$convert fio/bin/depend.lg2 fio/bin/depend.lg2 
$convert fio/bin/environ.lg2 fio/bin/environ.lg2 
$convert fio/bin/makefile.lg2 fio/bin/makefile.lg2 
$convert fio/bin/m2depend.lg2 fio/bin/m2depend.lg2 
$convert fio/bin/m2source.lg2 fio/bin/m2source.lg2 
$convert fio/test.bin/depend.lg2 fio/test.bin/depend.lg2 
$convert fio/test.bin/environ.lg2 fio/test.bin/environ.lg2 
$convert fio/test.bin/makefile.lg2 fio/test.bin/makefile.lg2 
$convert fio/test.bin/m2depend.lg2 fio/test.bin/m2depend.lg2 
$convert fio/test.bin/m2source.lg2 fio/test.bin/m2source.lg2 
$convert fio/test.dat/datafio.bad fio/test.dat/datafio.bad
$convert fio/test.dat/datafio.big fio/test.dat/datafio.big
$convert fio/test.dat/dfio#1 fio/test.dat/dfio#1
$convert fio/test_lwp.bin/depend.lg2 fio/test_lwp.bin/depend.lg2 
$convert fio/test_lwp.bin/environ.lg2 fio/test_lwp.bin/environ.lg2 
$convert fio/test_lwp.bin/makefile.lg2 fio/test_lwp.bin/makefile.lg2 
$convert fio/test_lwp.bin/m2depend.lg2 fio/test_lwp.bin/m2depend.lg2 
$convert fio/test_lwp.bin/m2source.lg2 fio/test_lwp.bin/m2source.lg2 
$convert fio/lwp.bin/depend.lg2 fio/lwp.bin/depend.lg2 
$convert fio/lwp.bin/environ.lg2 fio/lwp.bin/environ.lg2 
$convert fio/lwp.bin/makefile.lg2 fio/lwp.bin/makefile.lg2 
$convert fio/lwp.bin/m2depend.lg2 fio/lwp.bin/m2depend.lg2 
$convert fio/lwp.bin/m2source.lg2 fio/lwp.bin/m2source.lg2 
$convert gen/test.bin/depend.lg2 gen/test.bin/depend.lg2 
$convert gen/test.bin/environ.lg2 gen/test.bin/environ.lg2 
$convert gen/test.bin/makefile.lg2 gen/test.bin/makefile.lg2 
$convert gen/test.bin/m2depend.lg2 gen/test.bin/m2depend.lg2 
$convert gen/test.bin/m2source.lg2 gen/test.bin/m2source.lg2 
$convert gen/bin/depend.lg2 gen/bin/depend.lg2 
$convert gen/bin/environ.lg2 gen/bin/environ.lg2 
$convert gen/bin/makefile.lg2 gen/bin/makefile.lg2 
$convert gen/bin/m2depend.lg2 gen/bin/m2depend.lg2 
$convert gen/bin/m2source.lg2 gen/bin/m2source.lg2 
$convert gen/test_lwp.bin/depend.lg2 gen/test_lwp.bin/depend.lg2 
$convert gen/test_lwp.bin/environ.lg2 gen/test_lwp.bin/environ.lg2 
$convert gen/test_lwp.bin/makefile.lg2 gen/test_lwp.bin/makefile.lg2 
$convert gen/test_lwp.bin/m2depend.lg2 gen/test_lwp.bin/m2depend.lg2 
$convert gen/test_lwp.bin/m2source.lg2 gen/test_lwp.bin/m2source.lg2 
$convert gen/lwp.bin/depend.lg2 gen/lwp.bin/depend.lg2 
$convert gen/lwp.bin/environ.lg2 gen/lwp.bin/environ.lg2 
$convert gen/lwp.bin/makefile.lg2 gen/lwp.bin/makefile.lg2 
$convert gen/lwp.bin/m2source.lg2 gen/lwp.bin/m2source.lg2 
$convert gen/lwp.bin/m2depend.lg2 gen/lwp.bin/m2depend.lg2 
$convert tools/bin/depend.lg2 tools/bin/depend.lg2 
$convert tools/bin/environ.lg2 tools/bin/environ.lg2 
$convert tools/bin/makefile.lg2 tools/bin/makefile.lg2 
$convert tools/bin/m2depend.lg2 tools/bin/m2depend.lg2 
$convert tools/bin/m2source.lg2 tools/bin/m2source.lg2 
$convert demo/lwp.bin/depend.lg2 demo/lwp.bin/depend.lg2 
$convert demo/lwp.bin/environ.lg2 demo/lwp.bin/environ.lg2 
$convert demo/lwp.bin/makefile.lg2 demo/lwp.bin/makefile.lg2 
$convert demo/lwp.bin/m2depend.lg2 demo/lwp.bin/m2depend.lg2 
$convert demo/lwp.bin/m2source.lg2 demo/lwp.bin/m2source.lg2 
$convert io/bin/depend.lg2 io/bin/depend.lg2 
$convert io/bin/environ.lg2 io/bin/environ.lg2 
$convert io/bin/makefile.lg2 io/bin/makefile.lg2 
$convert io/bin/m2depend.lg2 io/bin/m2depend.lg2 
$convert io/bin/m2source.lg2 io/bin/m2source.lg2 
$convert io/test_lwp.bin/depend.lg2 io/test_lwp.bin/depend.lg2 
$convert io/test_lwp.bin/environ.lg2 io/test_lwp.bin/environ.lg2 
$convert io/test_lwp.bin/makefile.lg2 io/test_lwp.bin/makefile.lg2 
$convert io/test_lwp.bin/m2depend.lg2 io/test_lwp.bin/m2depend.lg2 
$convert io/test_lwp.bin/m2source.lg2 io/test_lwp.bin/m2source.lg2 
$convert io/test.bin/depend.lg2 io/test.bin/depend.lg2 
$convert io/test.bin/environ.lg2 io/test.bin/environ.lg2 
$convert io/test.bin/makefile.lg2 io/test.bin/makefile.lg2 
$convert io/test.bin/m2depend.lg2 io/test.bin/m2depend.lg2 
$convert io/test.bin/m2source.lg2 io/test.bin/m2source.lg2 
$convert io/lwp.bin/depend.lg2 io/lwp.bin/depend.lg2 
$convert io/lwp.bin/environ.lg2 io/lwp.bin/environ.lg2 
$convert io/lwp.bin/makefile.lg2 io/lwp.bin/makefile.lg2 
$convert io/lwp.bin/m2depend.lg2 io/lwp.bin/m2depend.lg2 
$convert io/lwp.bin/m2source.lg2 io/lwp.bin/m2source.lg2 
$convert fio/bin/depend.lg3 fio/bin/depend.lg3 
$convert fio/bin/environ.lg3 fio/bin/environ.lg3 
$convert fio/bin/makefile.lg3 fio/bin/makefile.lg3 
$convert fio/bin/m2depend.lg3 fio/bin/m2depend.lg3 
$convert fio/bin/m2source.lg3 fio/bin/m2source.lg3 
$convert fio/test.bin/depend.lg3 fio/test.bin/depend.lg3 
$convert fio/test.bin/environ.lg3 fio/test.bin/environ.lg3 
$convert fio/test.bin/makefile.lg3 fio/test.bin/makefile.lg3 
$convert fio/test.bin/m2depend.lg3 fio/test.bin/m2depend.lg3 
$convert fio/test.bin/m2source.lg3 fio/test.bin/m2source.lg3 
$convert fio/test_lwp.bin/depend.lg3 fio/test_lwp.bin/depend.lg3 
$convert fio/test_lwp.bin/environ.lg3 fio/test_lwp.bin/environ.lg3 
$convert fio/test_lwp.bin/makefile.lg3 fio/test_lwp.bin/makefile.lg3 
$convert fio/test_lwp.bin/m2depend.lg3 fio/test_lwp.bin/m2depend.lg3 
$convert fio/test_lwp.bin/m2source.lg3 fio/test_lwp.bin/m2source.lg3 
$convert fio/lwp.bin/depend.lg3 fio/lwp.bin/depend.lg3 
$convert fio/lwp.bin/environ.lg3 fio/lwp.bin/environ.lg3 
$convert fio/lwp.bin/makefile.lg3 fio/lwp.bin/makefile.lg3 
$convert fio/lwp.bin/m2depend.lg3 fio/lwp.bin/m2depend.lg3 
$convert fio/lwp.bin/m2source.lg3 fio/lwp.bin/m2source.lg3 
$convert gen/test.bin/depend.lg3 gen/test.bin/depend.lg3 
$convert gen/test.bin/environ.lg3 gen/test.bin/environ.lg3 
$convert gen/test.bin/makefile.lg3 gen/test.bin/makefile.lg3 
$convert gen/test.bin/m2depend.lg3 gen/test.bin/m2depend.lg3 
$convert gen/test.bin/m2source.lg3 gen/test.bin/m2source.lg3 
$convert gen/bin/depend.lg3 gen/bin/depend.lg3 
$convert gen/bin/environ.lg3 gen/bin/environ.lg3 
$convert gen/bin/makefile.lg3 gen/bin/makefile.lg3 
$convert gen/bin/m2depend.lg3 gen/bin/m2depend.lg3 
$convert gen/bin/m2source.lg3 gen/bin/m2source.lg3 
$convert gen/test_lwp.bin/depend.lg3 gen/test_lwp.bin/depend.lg3 
$convert gen/test_lwp.bin/environ.lg3 gen/test_lwp.bin/environ.lg3 
$convert gen/test_lwp.bin/makefile.lg3 gen/test_lwp.bin/makefile.lg3 
$convert gen/test_lwp.bin/m2depend.lg3 gen/test_lwp.bin/m2depend.lg3 
$convert gen/test_lwp.bin/m2source.lg3 gen/test_lwp.bin/m2source.lg3 
$convert gen/lwp.bin/depend.lg3 gen/lwp.bin/depend.lg3 
$convert gen/lwp.bin/environ.lg3 gen/lwp.bin/environ.lg3 
$convert gen/lwp.bin/makefile.lg3 gen/lwp.bin/makefile.lg3 
$convert gen/lwp.bin/m2source.lg3 gen/lwp.bin/m2source.lg3 
$convert gen/lwp.bin/m2depend.lg3 gen/lwp.bin/m2depend.lg3 
$convert tools/bin/depend.lg3 tools/bin/depend.lg3 
$convert tools/bin/environ.lg3 tools/bin/environ.lg3 
$convert tools/bin/makefile.lg3 tools/bin/makefile.lg3 
$convert tools/bin/m2depend.lg3 tools/bin/m2depend.lg3 
$convert tools/bin/m2source.lg3 tools/bin/m2source.lg3 
$convert demo/lwp.bin/depend.lg3 demo/lwp.bin/depend.lg3 
$convert demo/lwp.bin/environ.lg3 demo/lwp.bin/environ.lg3 
$convert demo/lwp.bin/makefile.lg3 demo/lwp.bin/makefile.lg3 
$convert demo/lwp.bin/m2depend.lg3 demo/lwp.bin/m2depend.lg3 
$convert demo/lwp.bin/m2source.lg3 demo/lwp.bin/m2source.lg3 
$convert io/bin/depend.lg3 io/bin/depend.lg3 
$convert io/bin/environ.lg3 io/bin/environ.lg3 
$convert io/bin/makefile.lg3 io/bin/makefile.lg3 
$convert io/bin/m2depend.lg3 io/bin/m2depend.lg3 
$convert io/bin/m2source.lg3 io/bin/m2source.lg3 
$convert io/test_lwp.bin/depend.lg3 io/test_lwp.bin/depend.lg3 
$convert io/test_lwp.bin/environ.lg3 io/test_lwp.bin/environ.lg3 
$convert io/test_lwp.bin/makefile.lg3 io/test_lwp.bin/makefile.lg3 
$convert io/test_lwp.bin/m2depend.lg3 io/test_lwp.bin/m2depend.lg3 
$convert io/test_lwp.bin/m2source.lg3 io/test_lwp.bin/m2source.lg3 
$convert io/test.bin/depend.lg3 io/test.bin/depend.lg3 
$convert io/test.bin/environ.lg3 io/test.bin/environ.lg3 
$convert io/test.bin/makefile.lg3 io/test.bin/makefile.lg3 
$convert io/test.bin/m2depend.lg3 io/test.bin/m2depend.lg3 
$convert io/test.bin/m2source.lg3 io/test.bin/m2source.lg3 
$convert io/lwp.bin/depend.lg3 io/lwp.bin/depend.lg3 
$convert io/lwp.bin/environ.lg3 io/lwp.bin/environ.lg3 
$convert io/lwp.bin/makefile.lg3 io/lwp.bin/makefile.lg3 
$convert io/lwp.bin/m2depend.lg3 io/lwp.bin/m2depend.lg3 
$convert io/lwp.bin/m2source.lg3 io/lwp.bin/m2source.lg3 
$convert fio/bin/depend.sun fio/bin/depend.sun 
$convert fio/bin/environ.sun fio/bin/environ.sun 
$convert fio/bin/makefile.sun fio/bin/makefile.sun 
$convert fio/bin/m2depend.sun fio/bin/m2depend.sun 
$convert fio/bin/m2source.sun fio/bin/m2source.sun 
$convert fio/test.bin/depend.sun fio/test.bin/depend.sun 
$convert fio/test.bin/environ.sun fio/test.bin/environ.sun 
$convert fio/test.bin/makefile.sun fio/test.bin/makefile.sun 
$convert fio/test.bin/m2depend.sun fio/test.bin/m2depend.sun 
$convert fio/test.bin/m2source.sun fio/test.bin/m2source.sun 
$convert fio/test_lwp.bin/depend.sun fio/test_lwp.bin/depend.sun 
$convert fio/test_lwp.bin/environ.sun fio/test_lwp.bin/environ.sun 
$convert fio/test_lwp.bin/makefile.sun fio/test_lwp.bin/makefile.sun 
$convert fio/test_lwp.bin/m2depend.sun fio/test_lwp.bin/m2depend.sun 
$convert fio/test_lwp.bin/m2source.sun fio/test_lwp.bin/m2source.sun 
$convert fio/lwp.bin/depend.sun fio/lwp.bin/depend.sun 
$convert fio/lwp.bin/environ.sun fio/lwp.bin/environ.sun 
$convert fio/lwp.bin/makefile.sun fio/lwp.bin/makefile.sun 
$convert fio/lwp.bin/m2depend.sun fio/lwp.bin/m2depend.sun 
$convert fio/lwp.bin/m2source.sun fio/lwp.bin/m2source.sun 
$convert gen/test.bin/depend.sun gen/test.bin/depend.sun 
$convert gen/test.bin/environ.sun gen/test.bin/environ.sun 
$convert gen/test.bin/makefile.sun gen/test.bin/makefile.sun 
$convert gen/test.bin/m2depend.sun gen/test.bin/m2depend.sun 
$convert gen/test.bin/m2source.sun gen/test.bin/m2source.sun 
$convert gen/bin/depend.sun gen/bin/depend.sun 
$convert gen/bin/environ.sun gen/bin/environ.sun 
$convert gen/bin/makefile.sun gen/bin/makefile.sun 
$convert gen/bin/m2depend.sun gen/bin/m2depend.sun 
$convert gen/bin/m2source.sun gen/bin/m2source.sun 
$convert gen/test_lwp.bin/depend.sun gen/test_lwp.bin/depend.sun 
$convert gen/test_lwp.bin/environ.sun gen/test_lwp.bin/environ.sun 
$convert gen/test_lwp.bin/makefile.sun gen/test_lwp.bin/makefile.sun 
$convert gen/test_lwp.bin/m2depend.sun gen/test_lwp.bin/m2depend.sun 
$convert gen/test_lwp.bin/m2source.sun gen/test_lwp.bin/m2source.sun 
$convert gen/lwp.bin/depend.sun gen/lwp.bin/depend.sun 
$convert gen/lwp.bin/environ.sun gen/lwp.bin/environ.sun 
$convert gen/lwp.bin/makefile.sun gen/lwp.bin/makefile.sun 
$convert gen/lwp.bin/m2source.sun gen/lwp.bin/m2source.sun 
$convert gen/lwp.bin/m2depend.sun gen/lwp.bin/m2depend.sun 
$convert tools/bin/depend.sun tools/bin/depend.sun 
$convert tools/bin/environ.sun tools/bin/environ.sun 
$convert tools/bin/makefile.sun tools/bin/makefile.sun 
$convert tools/bin/m2depend.sun tools/bin/m2depend.sun 
$convert tools/bin/m2source.sun tools/bin/m2source.sun 
$convert demo/lwp.bin/depend.sun demo/lwp.bin/depend.sun 
$convert demo/lwp.bin/environ.sun demo/lwp.bin/environ.sun 
$convert demo/lwp.bin/makefile.sun demo/lwp.bin/makefile.sun 
$convert demo/lwp.bin/m2depend.sun demo/lwp.bin/m2depend.sun 
$convert demo/lwp.bin/m2source.sun demo/lwp.bin/m2source.sun 
$convert io/bin/depend.sun io/bin/depend.sun 
$convert io/bin/environ.sun io/bin/environ.sun 
$convert io/bin/makefile.sun io/bin/makefile.sun 
$convert io/bin/m2depend.sun io/bin/m2depend.sun 
$convert io/bin/m2source.sun io/bin/m2source.sun 
$convert io/test_lwp.bin/depend.sun io/test_lwp.bin/depend.sun 
$convert io/test_lwp.bin/environ.sun io/test_lwp.bin/environ.sun 
$convert io/test_lwp.bin/makefile.sun io/test_lwp.bin/makefile.sun 
$convert io/test_lwp.bin/m2depend.sun io/test_lwp.bin/m2depend.sun 
$convert io/test_lwp.bin/m2source.sun io/test_lwp.bin/m2source.sun 
$convert io/test.bin/depend.sun io/test.bin/depend.sun 
$convert io/test.bin/environ.sun io/test.bin/environ.sun 
$convert io/test.bin/makefile.sun io/test.bin/makefile.sun 
$convert io/test.bin/m2depend.sun io/test.bin/m2depend.sun 
$convert io/test.bin/m2source.sun io/test.bin/m2source.sun 
$convert io/lwp.bin/depend.sun io/lwp.bin/depend.sun 
$convert io/lwp.bin/environ.sun io/lwp.bin/environ.sun 
$convert io/lwp.bin/makefile.sun io/lwp.bin/makefile.sun 
$convert io/lwp.bin/m2depend.sun io/lwp.bin/m2depend.sun 
$convert io/lwp.bin/m2source.sun io/lwp.bin/m2source.sun 
if [ $convert = unix2dos ]; then
    # Move directories last
    mv io/test_sun_lwp.src io/testsunl.src
    mv gen/test_pc_lwp.src gen/testpclw.src
fi
